<?php declare(strict_types=1);
/*
 * (c) shopware AG <info@shopware.com>
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Cf\CookieFirst\Struct;

use Shopware\Core\Framework\Struct\Struct;

class StorefrontPageData extends Struct {
    /**
     * @var array
     */
    protected $config = [];

    /**
     * @var string
     */
    protected $configPath = 'CookieFirst.config.';

    /**
     * StorefrontPageData constructor.
     * @param array $pluginConfig
     */
    public function __construct(array $pluginConfig)
    {
        $this->setValues($pluginConfig, 'apiKey', '');
        $this->setValues($pluginConfig, 'showWidget', false);
    }

    /**
     * @return mixed
     */
    public function getConfig() : array
    {
        return $this->config;
    }

    /**
     * @param array $config
     */
    public function setConfig(array $config): void
    {
        $this->config = $config;
    }

    /**
     * @param array $pluginConfig
     * @param string $key
     * @param null $default
     */
    public function setValues(array $pluginConfig, string $key, $default = null): void
    {
        if(array_key_exists($this->configPath . $key, $pluginConfig)) {
            $this->config[$key] = $pluginConfig[$this->configPath . $key];
        }
        else {
            $this->config[$key] = $default;
        }
    }
}